@@ -49,7 +49,10 @@ async def it_streaming(i: ItemUrlFilter):
 
 def write_csv_header_to_gz(i):
     r = requests.get(i.lst_url[0], verify=False)
-    df = pd.read_csv(BytesIO(r.content), compression='gzip')
+    if i.lst_url[0][-3] == '.gz':
+        df = pd.read_csv(BytesIO(r.content), compression='gzip')
+    if i.lst_url[0][-4] == '.csv':
+        df = pd.read_csv(BytesIO(r.content))
     bytesio_gz = BytesIO()
     with gzip.open(bytesio_gz, 'wb') as f:
         f.write((','.join(df.columns) + '\n').encode('utf-8'))
@@ -73,5 +76,5 @@ async def streaming_get(md5_hex):
     return StreamingResponse(it_streaming(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20429):
+def server(host='0.0.0.0', int_port=20430):
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
